==> RSTouchscreenNG-1.3.0.zip: RSTouchscreenNG/projects/front-ui/src/lib/modals/float-selection-keyboard.service.ts <==
/* (C) 2016-2021 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, Injectable} from "@angular/core";
import {RSModal} from "./rsModal.component";
import {RSModalViewComponent} from "./modal-view.component";
import {DomSanitizer, SafeHtml} from "@angular/platform-browser";

@Component({
    selector: "rs-float-selection-keyboard-modal",
    template: `<div class="rs-string-keyboard-modal">
      <rs-modal-head><h1><span [innerHTML]="head"></span><div class="close" (rsClick)="modal.cancel()"><i class="fa fa-close"></i></div></h1></rs-modal-head>
    <rs-modal-content>
        <div style="padding:2px 5px">
            <div class="input" (rsClick)="selected=!selected"><span [class]="(selected ? 'inverted' : '')" [innerHTML]="valueShow"></span><div class="unit" *ngIf="options.unit" [innerHTML]="options.unit"></div></div>
        </div>
        <div class="error" [innerHTML]="error"></div>
        <rs-floating-selection-keyboard (send)="send($event)" (selectedChange)="selected=$event" [selected]="selected" [value]="value" (valueChange)="update($event)" [canSend]="canSend"></rs-floating-selection-keyboard>
    </rs-modal-content>
</div>`
})
export class RSFloatSelectionKeyboardModalComponent {
    value = "";
    valueShow = "";
    head: SafeHtml = "";
    error = "&nbsp;";
    canSend = true;
    page = 0; // 0 = a-z, 1 = A-Z, 2 = numbers/symbols
    options: any = {};
    hasError = false;
    selected: Boolean = true;

    constructor(public modal: RSModalViewComponent,
                private sanitizer: DomSanitizer) {
        this.options = this.modal.data;
        this.value = this.modal.data.defaultValue;
        this.head = this.sanitizer.bypassSecurityTrustHtml(this.modal.data.head);
        this.update(this.value);
    }

    update(newVal: string): void {
        this.hasError = false;
        this.value = newVal;
        if (newVal.length === 0) {
            this.canSend = false;
        } else {
            const floatVal = parseFloat(newVal);

            if (this.options.min) {
              const roundedMin = (parseFloat(this.options.min) * 1000) / 1000;
              if (floatVal < roundedMin) {
                this.hasError = true;
                this.error = "<?php _('Min. value is @!') ?>".replace("@", roundedMin.toString());
              }
            }
            if (this.options.max) {
              const roundedMax = Math.round(parseFloat(this.options.max) * 1000) / 1000;
              if (floatVal > roundedMax) {
                this.hasError = true;
                this.error = "<?php _('Max. value is @!') ?>".replace("@", (Math.round(parseFloat(this.options.max) * 1000) / 1000).toString());
              }
            }
            this.canSend = !this.hasError;
        }

        this.valueShow = this.value.split(" ").join("&nbsp;");
        if (this.valueShow.length === 0) {
            this.valueShow = "&nbsp;";
        }
        if (!this.hasError) {
            this.error = "&nbsp;";
        }
    }

    send(val?: any): void {
        if (val !== undefined) {
            this.modal.close(parseFloat(val));
        }
        if (this.hasError === false) {
            this.modal.close(parseFloat(this.value));
        }
    }
}


@Injectable()
export class RSFloatSelectionKeyboard {
    constructor(public modal: RSModal) {
    }

    getFloat(oldValue: number, head: string, options?: any): Promise<any> {
        return this.modal.show(RSFloatSelectionKeyboardModalComponent,
            Object.assign({head: head, modalClass: "modal-noborder", unit: "", defaultValue: "" + oldValue}, options));
    }
}

==> RSTouchscreenNG-1.4.16.zip: RSTouchscreenNG/projects/front-ui/src/lib/modals/float-selection-keyboard.service.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, Injectable} from "@angular/core";
import {RSModal} from "./rsModal.component";
import {RSModalViewComponent} from "./modal-view.component";
import {DomSanitizer, SafeHtml} from "@angular/platform-browser";

@Component({
  // eslint-disable-next-line @angular-eslint/component-selector
    selector: "rs-float-selection-keyboard-modal",
    template: `<div class="rs-string-keyboard-modal">
      <rs-modal-head><h1><span [innerHTML]="head"></span><div class="close" (rsClick)="modal.cancel()"><i class="fa fa-close"></i></div></h1></rs-modal-head>
    <rs-modal-content>
        <div style="padding:2px 5px">
            <div class="input" (rsClick)="selected=!selected"><span [class]="(selected ? 'inverted' : '')" [innerHTML]="valueShow"></span><div class="unit" *ngIf="options.unit" [innerHTML]="options.unit"></div></div>
        </div>
        <div class="error" [innerHTML]="error"></div>
        <rs-floating-selection-keyboard (send)="send($event)" (selectedChange)="selected=$event" [selected]="selected" [value]="value" (valueChange)="update($event)" [canSend]="canSend"></rs-floating-selection-keyboard>
    </rs-modal-content>
</div>`
})
export class RSFloatSelectionKeyboardModalComponent {
    value = "";
    valueShow = "";
    head: SafeHtml = "";
    error = "&nbsp;";
    canSend = true;
    page = 0; // 0 = a-z, 1 = A-Z, 2 = numbers/symbols
    options: any = {};
    hasError = false;
    selected: Boolean = true;

    constructor(public modal: RSModalViewComponent,
                private sanitizer: DomSanitizer) {
        this.options = this.modal.data;
        this.value = this.modal.data.defaultValue;
        this.head = this.sanitizer.bypassSecurityTrustHtml(this.modal.data.head);
        this.update(this.value);
    }

    update(newVal: string): void {
        this.hasError = false;
        this.value = newVal;
        if (newVal.length === 0) {
            this.canSend = false;
        } else {
            const floatVal = parseFloat(newVal);

            if (this.options.min) {
              const roundedMin = Math.round(parseFloat(this.options.min) * 1000) / 1000;
              if (floatVal < roundedMin) {
                this.hasError = true;
                this.error = "<?php _('Min. value is @!') ?>".replace("@", roundedMin.toString());
              }
            }
            if (this.options.max) {
              const roundedMax = Math.round(parseFloat(this.options.max) * 1000) / 1000;
              if (floatVal > roundedMax) {
                this.hasError = true;
                this.error = "<?php _('Max. value is @!') ?>".replace("@", (Math.round(parseFloat(this.options.max) * 1000) / 1000).toString());
              }
            }
            this.canSend = !this.hasError;
        }

        this.valueShow = this.value.split(" ").join("&nbsp;");
        if (this.valueShow.length === 0) {
            this.valueShow = "&nbsp;";
        }
        if (!this.hasError) {
            this.error = "&nbsp;";
        }
    }

    send(val?: any): void {
        if (val !== undefined) {
            this.modal.close(parseFloat(val));
        }
        if (this.hasError === false) {
            this.modal.close(parseFloat(this.value));
        }
    }
}


@Injectable()
export class RSFloatSelectionKeyboard {
    constructor(public modal: RSModal) {
    }

    getFloat(oldValue: number, head: string, options?: any): Promise<any> {
        return this.modal.show(RSFloatSelectionKeyboardModalComponent,
            Object.assign({head: head, modalClass: "modal-noborder", unit: "", defaultValue: "" + oldValue}, options));
    }
}
